epoll_ctl

Function epoll_ctl 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn epoll_ctl( epfd: c_int, op: c_int, fd: c_int, event: *mut epoll_event, ) -> c_int
Non-POSIX, see https://man7.org/linux/man-pages/man2/epoll_ctl.2.html.

Add, modify, or remove entries in the interest list of the epoll instance referred to by the file descriptor epfd.

Upon success, returns 0. Upon error, returns -1 and sets errno to indicate the error.