epoll_pwait

Function epoll_pwait 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn epoll_pwait( epfd: c_int, events: *mut epoll_event, maxevents: c_int, timeout: c_int, sigmask: *const sigset_t, ) -> c_int
Non-POSIX, see https://man7.org/linux/man-pages/man2/epoll_wait.2.html.

Allows an application to safely wait until either a file descriptor becomes ready or a signal is caught.

If sigmask is NULL, calling this function is equivalent to epoll_wait().

Upon success, returns the number of file descriptors ready for the requested I/O operation, or 0 if no file descriptor became ready during the requested timeout. Upon failure, returns -1 and sets errno to indicate the error.