#[unsafe(no_mangle)]pub extern "C" fn epoll_create(_size: c_int) -> c_intExpand description
Non-POSIX, see https://man7.org/linux/man-pages/man2/epoll_create.2.html.
Creates a file descriptor referring to the new epoll instance.
Upon success, returns a file descriptor (a nonnegative integer). Upon
error, -1 is returned and errno set to indicate the error.
Implementation
The _size parameter is deliberately unused as it is no longer required.
This function simply calls epoll_create1.